Crate signet_evm

Crate signet_evm 

Signet EVM

Modules

sys
System structs and types.

Structs

BlockResult
Output of a block execution.
ExecutionOutcome
The outcome of a block execution, containing the bundle state, receipts, and the first block number in the execution.
Framed
Events associated with frame boundaries.
OrderDetector
Inspector used to detect Signet Orders and inform the builder of the fill requirements.
SignetDriver
A driver for the Signet EVM

Traits

SignetInspector
Inspector containing an accessible OrderDetector.

Functions

signet_evm
Create a new EVM with the given database.
signet_evm_with_inspector
Create a new EVM with the given database and inspector.
signet_precompiles
Create a set of precompiles for the Signet EVM.

Type Aliases

DriveBundleResult
The result of driving a bundle.
EvmErrored
A Trevm that encountered an error during transaction execution.
EvmNeedsBlock
A Trevm that requires a Block and contains no outputs. This EVM has not yet executed any transactions or state changes.
EvmNeedsCfg
A Trevm that requires a Cfg.
EvmNeedsTx
A Trevm that requires a Tx.
EvmReady
A Trevm that is ready to execute a transaction.
EvmTransacted
A Trevm that encountered an error during transaction execution.
FramedFilleds
A Framed containing RollupOrders::Filled instances.
FramedOrders
A Framed containing RollupOrders::Order instances.
RunTxResult
The result of running transactions for a block driver.
SignetLayered
Layered inspector containing an OrderDetector.