OrderDetector

Struct OrderDetector 

pub struct OrderDetector { /* private fields */ }
Inspector used to detect Signet Orders and inform the builder of the fill requirements.

This inspector is intended to be used with trevm. The EVM driver should

The SignetDriver has an example of this in the check_fills_and_accept function.

The OrderDetector allows an inner inspector to be used as well. This is useful for tracers and other tools that need to inspect the EVM state.

Implementations

Source

impl OrderDetector

pub fn new(contracts: HashSet<Address>, chain_id: u64, fills_only: bool) -> Self

Create a new OrderDetector with the given contracts addresses, chain_id, and fills_only flag.

pub fn for_rollup(constants: SignetSystemConstants) -> OrderDetector

Create a new OrderDetector for the rollup environment. This detector will detect both orders and fills.

pub fn for_host(constants: SignetSystemConstants) -> OrderDetector

Create a new OrderDetector for the host environment. This detector will only detect fills.

pub fn is_contract(&self, address: Address) -> bool

Get the address of the orders contract.

pub const fn chain_id(&self) -> u64

Get the chain ID.

pub fn take(&mut self) -> (FramedOrders, FramedFilleds)

Take the orders from the inspector, clearing it.

pub fn take_aggregates(&mut self) -> (AggregateFills, AggregateOrders)

Take the orders from the inspector, clearing it, and convert them to aggregate orders.

pub fn into_parts(self) -> (FramedOrders, FramedFilleds)

Take the inner inspector and the framed events.

pub const fn orders(&self) -> &FramedOrders

Get a reference to the framed RollupOrders::Order events.

pub const fn filleds(&self) -> &FramedFilleds

Get a reference to the framed RollupOrders::Filled events.