pub struct SignetDriver<'a, 'b, C: Extractable> { /* private fields */ }Expand description
A driver for the Signet EVM
Implementations
Sourceimpl<'a, 'b, C: Extractable> SignetDriver<'a, 'b, C>
impl<'a, 'b, C: Extractable> SignetDriver<'a, 'b, C>
Sourcepub fn new(
extracts: &'a Extracts<'b, C>,
to_alias: HashSet<Address>,
to_process: VecDeque<TransactionSigned>,
parent: SealedHeader,
constants: SignetSystemConstants,
) -> Self
pub fn new( extracts: &'a Extracts<'b, C>, to_alias: HashSet<Address>, to_process: VecDeque<TransactionSigned>, parent: SealedHeader, constants: SignetSystemConstants, ) -> Self
Create a new driver.
Sourcepub const fn extracts(&self) -> &Extracts<'b, C>
pub const fn extracts(&self) -> &Extracts<'b, C>
Get the extracts being executed by the driver.
Sourcepub const fn parent(&self) -> &SealedHeader
pub const fn parent(&self) -> &SealedHeader
Get the parent header.
Sourcepub const fn constants(&self) -> &SignetSystemConstants
pub const fn constants(&self) -> &SignetSystemConstants
Get the system constants.
Sourcepub fn beneficiary(&self) -> Address
pub fn beneficiary(&self) -> Address
beneficiary of the current block.
Sourcepub const fn base_fee_recipient(&self) -> Address
pub const fn base_fee_recipient(&self) -> Address
Base fee beneficiary of the current block.
Sourcepub const fn payable_gas_used(&self) -> u64
pub const fn payable_gas_used(&self) -> u64
Get the cumulative gas used in the block (so far). This excludes gas used by enters and enter token events.
Sourcepub fn cumulative_gas_used(&self) -> u64
pub fn cumulative_gas_used(&self) -> u64
Get the cumulative gas used in the block, including the gas used by enters and enter token events.
Sourcepub fn finish(self) -> (RecoveredBlock, Vec<ReceiptEnvelope>)
pub fn finish(self) -> (RecoveredBlock, Vec<ReceiptEnvelope>)
Consume the driver, producing the sealed block and receipts.
Sourcepub fn finish_trevm<Db, Insp>(
self,
trevm: EvmNeedsBlock<State<Db>, Insp>,
) -> BlockResult
pub fn finish_trevm<Db, Insp>( self, trevm: EvmNeedsBlock<State<Db>, Insp>, ) -> BlockResult
Consume the driver and trevm, producing a BlockResult.