Signet EVM
Modules
- sys
- System structs and types.
Structs
- Block
Result - Output of a block execution.
- Execution
Outcome - The outcome of a block execution, containing the bundle state, receipts, and the first block number in the execution.
- Framed
- Events associated with frame boundaries.
- Order
Detector - Inspector used to detect Signet Orders and inform the builder of the fill requirements.
- Signet
Driver - A driver for the Signet EVM
Traits
- Signet
Inspector - Inspector containing an accessible
OrderDetector.
Functions
- signet_
evm - Create a new EVM with the given database.
- signet_
evm_ with_ inspector - Create a new EVM with the given database and inspector.
- signet_
precompiles - Create a set of precompiles for the Signet EVM.
Type Aliases
- Drive
Bundle Result - The result of driving a bundle.
- EvmErrored
- A
Trevmthat encountered an error during transaction execution. - EvmNeeds
Block - A
Trevmthat requires aBlockand contains no outputs. This EVM has not yet executed any transactions or state changes. - EvmNeeds
Cfg - A
Trevmthat requires aCfg. - EvmNeeds
Tx - A
Trevmthat requires aTx. - EvmReady
- A
Trevmthat is ready to execute a transaction. - EvmTransacted
- A
Trevmthat encountered an error during transaction execution. - Framed
Filleds - A
FramedcontainingRollupOrders::Filledinstances. - Framed
Orders - A
FramedcontainingRollupOrders::Orderinstances. - RunTx
Result - The result of running transactions for a block driver.
- Signet
Layered - Layered inspector containing an
OrderDetector.