pub struct OrderDetector { /* private fields */ }Expand description
Inspector used to detect Signet Orders and inform the builder of the fill requirements.
This inspector is intended to be used with trevm. The EVM driver should
- call
OrderDetector::take_aggregatesto get the aggregate orders and fills produced by that transaction. - ensure that net fills are sufficient to cover the order inputs via
AggregateFills::checked_remove_ru_tx_events. - reject transactions which are not sufficiently filled.
The SignetDriver has an example of this in the check_fills_and_accept
function.
The OrderDetector allows an inner inspector to be used as well. This is
useful for tracers and other tools that need to inspect the EVM state.
Implementations
Sourceimpl OrderDetector
impl OrderDetector
Sourcepub fn new(contracts: HashSet<Address>, chain_id: u64, fills_only: bool) -> Self
pub fn new(contracts: HashSet<Address>, chain_id: u64, fills_only: bool) -> Self
Create a new OrderDetector with the given contracts addresses,
chain_id, and fills_only flag.
Sourcepub fn for_rollup(constants: SignetSystemConstants) -> OrderDetector
pub fn for_rollup(constants: SignetSystemConstants) -> OrderDetector
Create a new OrderDetector for the rollup environment. This detector
will detect both orders and fills.
Sourcepub fn for_host(constants: SignetSystemConstants) -> OrderDetector
pub fn for_host(constants: SignetSystemConstants) -> OrderDetector
Create a new OrderDetector for the host environment. This detector
will only detect fills.
Sourcepub fn is_contract(&self, address: Address) -> bool
pub fn is_contract(&self, address: Address) -> bool
Get the address of the orders contract.
Sourcepub fn take(&mut self) -> (FramedOrders, FramedFilleds)
pub fn take(&mut self) -> (FramedOrders, FramedFilleds)
Take the orders from the inspector, clearing it.
Sourcepub fn take_aggregates(&mut self) -> (AggregateFills, AggregateOrders)
pub fn take_aggregates(&mut self) -> (AggregateFills, AggregateOrders)
Take the orders from the inspector, clearing it, and convert them to aggregate orders.
Sourcepub fn into_parts(self) -> (FramedOrders, FramedFilleds)
pub fn into_parts(self) -> (FramedOrders, FramedFilleds)
Take the inner inspector and the framed events.
Sourcepub const fn orders(&self) -> &FramedOrders
pub const fn orders(&self) -> &FramedOrders
Get a reference to the framed RollupOrders::Order events.
Sourcepub const fn filleds(&self) -> &FramedFilleds
pub const fn filleds(&self) -> &FramedFilleds
Get a reference to the framed RollupOrders::Filled events.